=========
 sc2bank
=========

.. image:: https://travis-ci.org/winny-/sc2bank.png?branch=master
   :target: https://travis-ci.org/winny-/sc2bank
   :alt: Build Status
.. image:: https://pypip.in/v/sc2bank/badge.png
   :target: https://pypi.python.org/pypi/sc2bank
   :alt: Latest PyPi Package
.. image:: https://coveralls.io/repos/winny-/sc2bank/badge.png?branch=master
   :target: https://coveralls.io/r/winny-/sc2bank?branch=master
   :alt: Coverage Status

Python module to sign StarCraft II bank files which are used to save stats in Arcade.

.. image:: https://i.imgur.com/z5cmEz7.png
   :alt: The Gui Module

Installation
============
Any platform
------------
1. Install PyQt4 for the GUI.
2. :code:`pip install sc2bank`

Prepackaged GUI Releases
------------------------
* Mac 0.2 https://www.dropbox.com/s/co1r0dtdq2lb1d6/sc2bank.app.zip
* Windows 0.2 https://www.dropbox.com/s/qo41t2dod7kpzny/sc2bank.exe.zip

How to use
==========
From PyPi (Pip, Easy_install)
-----------------------------
* GUI: :code:`python -m sc2bank.gui`
* CLI: :code:`python -m sc2bank path/to/bank.SC2Bank`

From Prepackaged GUI Release
----------------------------
Unzip the file and double click on the EXE/APP file.

Contributing and Feedback
==========================
sc2bank@fastmail.fm is always listening. Open an issue with the file and metadata
(e.g. the file's path and your User ID, bank's name, bank's author). Use KISS philosophy
when contributing code.
